From 7f18015321c5d452332441f5fbc80fd2bcfe9319 Mon Sep 17 00:00:00 2001
From: Akash Mehrotra <mehrotra.akash@gmail.com>
Date: Tue, 21 Jun 2011 00:34:34 +0530
Subject: [PATCH] luahttp can access and modify equalizer bands

---
 modules/lua/libs/equalizer.c          |   85 +++++++++++++++++++++++++++++++++
 share/lua/http/requests/README.txt    |   16 ++++++
 share/lua/http/requests/equalizer.xml |   19 +++++++-
 3 files changed, 118 insertions(+), 2 deletions(-)

diff --git a/modules/lua/libs/equalizer.c b/modules/lua/libs/equalizer.c
index f414974..8a47403 100644
--- a/modules/lua/libs/equalizer.c
+++ b/modules/lua/libs/equalizer.c
@@ -81,9 +81,94 @@ static int vlclua_preamp_set( lua_State *L )
     return 0;
 }
 
+/*****************************************************************************
+Bands:
+Band 0:  60 Hz
+Band 1: 170 Hz
+Band 2: 310 Hz
+Band 3: 600 Hz
+Band 4:  1 kHz
+Band 5:  3 kHz
+Band 6:  6 kHz
+Band 7: 12 kHz
+Band 8: 14 kHz
+Band 9: 16 kHz
+*****************************************************************************/
+/*****************************************************************************
+* Get the equalizer level for the specified band
+*****************************************************************************/
+static int vlclua_equalizer_get( lua_State *L )
+{
+    input_thread_t *p_input = vlclua_get_input_internal( L );
+    if( p_input )
+    {
+        int i_offset = 0;
+        float level;
+        aout_instance_t *p_aout = input_GetAout( p_input );
+        int bandid = luaL_checknumber( L, 1 );
+        char *bands = var_GetString( p_aout, "equalizer-bands" );
+        if(bandid == 0)
+            level=strtof( bands , NULL );
+        else
+        {
+            while( bandid >= 0 )
+            {
+                i_offset++;
+                if( bands[i_offset] == ' ' && bands[i_offset+1] != ' ' )
+                    bandid--;
+            }
+            level=strtof( bands+i_offset , NULL );
+       }
+
+        lua_pushnumber( L, level );
+
+        vlc_object_release( p_aout );
+        vlc_object_release( p_input );
+        return 1;
+    }
+    return 0;
+}
+/*****************************************************************************
+* Set the equalizer level for the specified band
+*****************************************************************************/
+static int vlclua_equalizer_set( lua_State *L )
+{
+    input_thread_t *p_input = vlclua_get_input_internal( L );
+    if( p_input )
+    {
+        int i_pos = 0 , j = 0;
+        aout_instance_t *p_aout = input_GetAout( p_input );
+        int bandid = luaL_checknumber( L, 1 );
+        float level = luaL_checknumber( L, 2 );
+        char *bands = var_GetString( p_aout, "equalizer-bands" );
+        char newstr[7];
+        while( j != bandid )
+        {
+            i_pos++;
+            if( bands[i_pos] == '.' )
+            {
+                i_pos++;
+                j++;
+            }
+        }
+        if( bandid != 0 )
+            i_pos++;
+        sprintf(newstr,"%6.1f",level);
+        for(int i=0;i<6;i++)
+            bands[i_pos+i]=newstr[i];
+        var_SetString( p_aout, "equalizer-bands",bands );
+
+        vlc_object_release( p_aout );
+        vlc_object_release( p_input );
+        return 1;
+    }
+    return 0;
+}
 static const luaL_Reg vlclua_equalizer_reg[] = {
     { "preampget", vlclua_preamp_get },
     { "preampset", vlclua_preamp_set },
+    { "equalizerget", vlclua_equalizer_get },
+    { "equalizerset", vlclua_equalizer_set },
     { NULL, NULL }
 };
 
diff --git a/share/lua/http/requests/README.txt b/share/lua/http/requests/README.txt
index a327ff2..d32e70b 100644
--- a/share/lua/http/requests/README.txt
+++ b/share/lua/http/requests/README.txt
@@ -129,3 +129,19 @@ equalizer.xml:
 =============
 >command=preamp&val=<val in dB> 
  sets the preamp value, must be >=-20 and <=20
+
+>command=equalizer&band=<band>&val=<gain in dB, must be >=-20 and <=20)
+
+<Displays the equalizer band gains.
+
+Band 0:  60 Hz
+Band 1: 170 Hz
+Band 2: 310 Hz
+Band 3: 600 Hz
+Band 4:  1 kHz
+Band 5:  3 kHz
+Band 6:  6 kHz
+Band 7: 12 kHz
+Band 8: 14 kHz
+Band 9: 16 kHz
+
diff --git a/share/lua/http/requests/equalizer.xml b/share/lua/http/requests/equalizer.xml
index 7476487..471199c 100644
--- a/share/lua/http/requests/equalizer.xml
+++ b/share/lua/http/requests/equalizer.xml
@@ -28,11 +28,26 @@ vim:syntax=lua
 
 local command = _GET['command']
 local val = _GET['val']
+local band = _GET['band']
 function round(what, precision)
-   return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision)
+if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision) else return nil end
+end
+if command == "preamp" then vlc.equalizer.preampset(val) 
+elseif command == "equalizer" then vlc.equalizer.equalizerset(band,val)
 end
-if command == "preamp" then vlc.equalizer.preampset(val) end
 ?>
 <root>
   <preamp><?vlc print(round(vlc.equalizer.preampget(),2)) ?></preamp>
+  <equalizer>
+    <band0><?vlc print(round(vlc.equalizer.equalizerget(0),1)) ?></band0>
+    <band1><?vlc print(round(vlc.equalizer.equalizerget(1),1)) ?></band1>
+    <band2><?vlc print(round(vlc.equalizer.equalizerget(2),1)) ?></band2>
+    <band3><?vlc print(round(vlc.equalizer.equalizerget(3),1)) ?></band3>
+    <band4><?vlc print(round(vlc.equalizer.equalizerget(4),1)) ?></band4>
+    <band5><?vlc print(round(vlc.equalizer.equalizerget(5),1)) ?></band5>
+    <band6><?vlc print(round(vlc.equalizer.equalizerget(6),1)) ?></band6>
+    <band7><?vlc print(round(vlc.equalizer.equalizerget(7),1)) ?></band7>
+    <band8><?vlc print(round(vlc.equalizer.equalizerget(8),1)) ?></band8>
+    <band9><?vlc print(round(vlc.equalizer.equalizerget(9),1)) ?></band9>
+  </equalizer>
 </root>
-- 
1.7.4.1

